aboutsummaryrefslogtreecommitdiff
path: root/src/argaze/GazeFeatures.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/argaze/GazeFeatures.py')
-rw-r--r--src/argaze/GazeFeatures.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/argaze/GazeFeatures.py b/src/argaze/GazeFeatures.py
index d6011a0..fd43824 100644
--- a/src/argaze/GazeFeatures.py
+++ b/src/argaze/GazeFeatures.py
@@ -146,8 +146,8 @@ class GazeMovement():
duration: float = field(init=False)
"""Inferred duration from first and last timestamps."""
- distance: float = field(init=False)
- """Inferred distance from first and last positions."""
+ amplitude: float = field(init=False)
+ """Inferred amplitude from first and last positions."""
def __post_init__(self):
@@ -160,10 +160,10 @@ class GazeMovement():
_, start_position = self.positions.first
_, end_position = self.positions.last
- distance = numpy.linalg.norm( numpy.array(start_position.value) - numpy.array(end_position.value))
+ amplitude = numpy.linalg.norm( numpy.array(start_position.value) - numpy.array(end_position.value))
- # Update frozen distance attribute
- object.__setattr__(self, 'distance', distance)
+ # Update frozen amplitude attribute
+ object.__setattr__(self, 'amplitude', amplitude)
def __str__(self) -> str:
"""String display"""